#
# spec file for package libunistring
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define lname	libunistring2
Name:           libunistring
Version:        0.9.10
Release:        1.1
Summary:        GNU Unicode string library
License:        LGPL-3.0-or-later OR GPL-2.0-only
Group:          Development/Libraries/C and C++
Url:            http://www.gnu.org/software/libunistring/
Source0:        http://ftp.gnu.org/gnu/libunistring/libunistring-%{version}.tar.xz
Source1:        http://ftp.gnu.org/gnu/libunistring/libunistring-%{version}.tar.xz.sig
Source2:        http://savannah.gnu.org/project/memberlist-gpgkeys.php?group=libunistring&download=1#/%{name}.keyring
Source3:        baselibs.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{?suse_version } == 1110
BuildRequires:  xz
%endif

%description
This portable C library implements Unicode string types in three flavours:
(UTF-8, UTF-16, UTF-32), together with functions for character processing
(names, classifications, properties) and functions for string processing
(iteration, formatted output, width, word breaks, line breaks, normalization,
case folding and regular expressions).

%package devel
Summary:        Development files for the GNU Unicode string library
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}
Requires:       info
# Obsoletes added in 12.2
Obsoletes:      %{name} < %{version}-%{release}
Provides:       %{name} = %{version}-%{release}

%description devel
Development files for programs using libunistring and documentation
for UniString library.

%package -n %{lname}
Summary:        GNU Unicode string library
Group:          System/Libraries

%description -n %{lname}
This portable C library implements Unicode string types in three flavours:
(UTF-8, UTF-16, UTF-32), together with functions for character processing
(names, classifications, properties) and functions for string processing
(iteration, formatted output, width, word breaks, line breaks, normalization,
case folding and regular expressions).

%prep
%setup -q

%build
%configure --disable-static --disable-rpath --docdir=%{_docdir}/%{name}
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} INSTALL="install -p" install
cp AUTHORS NEWS README HACKING DEPENDENCIES THANKS ChangeLog %{buildroot}/%{_docdir}/%{name}
rm -f %{buildroot}/%{_infodir}/dir
rm -f %{buildroot}/%{_libdir}/libunistring.la

%check
%if ! 0%{?qemu_user_space_build}
# test-malloca seem not to be suitable for ix86 obs worker
# (locally passes, obs worker stucks -- )
%ifarch %ix86
sed -i 's:50000:50:g' tests/test-malloca.c
%endif
# do not run tests in parallel, it stucks randomly
make check
%endif

%files -n %{lname}
%defattr(-,root,root)
%{_libdir}/libunistring.so.2*

%files devel
%defattr(-,root,root)
%{_docdir}/%{name}
%{_infodir}/libunistring.info*
%{_libdir}/libunistring.so
%{_includedir}/unistring
%{_includedir}/*.h

%post -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig
%post devel
/sbin/install-info %{_infodir}/libunistring.info.gz %{_infodir}/dir || :

%preun devel
if [ "$1" = 0 ]; then
   /sbin/install-info --delete %{_infodir}/libunistring.info.gz %{_infodir}/dir || :
fi

%changelog
* Mon Mar 29 2021 pgajdos@suse.com
- version update to 0.9.10 [bsc#1183794]
  * The functions
    u8_casing_prefix_context, u8_casing_prefixes_context,
    u8_casing_suffix_context, u8_casing_suffixes_context,
    u16_casing_prefix_context, u16_casing_prefixes_context,
    u16_casing_suffix_context, u16_casing_suffixes_context,
    u32_casing_prefix_context, u32_casing_prefixes_context,
    u32_casing_suffix_context, u32_casing_suffixes_context,
    that are documented since version 0.9.1, are now actually
    implemented.
  * bump gnulib version
* Sat Mar  3 2018 jengelh@inai.de
- Fix RPM groups and summaries.
* Wed Feb 28 2018 astieger@suse.com
- update to 0.9.9:
  * Fixed a multithread-safety bug
* Fri Dec  1 2017 astieger@suse.com
- update to 0.9.8:
  * The data tables and line breaking algorithm have been updated
    to Unicode version 9.0.0
  * In the include file unigbrk.h, the function uc_grapheme_breaks
    has been added to accommodate the new UAX#29 rules involving 3
    or more consecutive characters
* Fri Aug 18 2017 pgajdos@suse.com
- try to not run tests in parallel, make check stucks randomly
* Fri May  5 2017 pgajdos@suse.com
- updated to 0.9.7:
  * license change
  * build system changes
* Tue Jan  3 2017 mlin@suse.com
- Add baselibs.conf to generate -32bit packages
* Thu Jul  9 2015 astieger@suse.com
- GNU libunistring 0.9.6:
  * The data tables and line breaking algorithm have been updated
    to Unicode version 8.0.0.
- add keyring and verify source signature
- fix SLE 11 SP3 build
* Thu Feb 19 2015 p.drouand@gmail.com
- Update to version 0.9.5
  * The data tables and line breaking algorithm have been updated
    to Unicode version 7.0.0.
  * In the include file uniname.h, the function unicode_name_character
    has been extended to look for name aliases.
- Remove patches merged on upstream release
  * libunistring-gnulib-ppc64le.patch
  * libunistring-parallel-make.patch
- Use download Url as source
- Remove autoconf, automake and libtool require; not needed anymore
- Bump so version to 2
  libunistring0 > libunistring2
* Tue Mar  4 2014 pgajdos@suse.com
- fix parallel build
  * added parallel-make.patch [bnc#866723] (private)
* Wed Dec 18 2013 uweigand@de.ibm.com
- libunistring-gnulib-ppc64le.patch: Fix imported gnulib long double
  math tests for little-endian PowerPC.
* Fri Mar 16 2012 cfarrell@suse.com
- license update: LGPL-3.0+ and GPL-3.0+
  Numerous files in tests/ and woedll are GPL-3.0+ licensed. Either put
  them in a separate GPL-3.0+ labelled subpackage or use this label for the
  main License: line
* Sun Mar 11 2012 jengelh@medozas.de
- Nuke unnecessary libunistring binary package: move documentation
  files to devel subpackage
* Mon Jan 30 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
- Parallel building using %%_smp_mflags
* Fri Sep 30 2011 crrodriguez@opensuse.org
- Workaround qemu-arm bugs.
* Mon Aug 30 2010 pgajdos@suse.cz
- updated to version 0.9.3:
  * Bug fixes in unistr.h functions:
  - The functions u16_to_u32, u16_to_u8, u8_to_u32, u8_to_u16 now fail when
    the argument is not valid. Previously, they returned a converted string
    where invalid parts were each replaced with U+FFFD.
  - The function u8_mbsnlen now counts an incomplete character at the end
    of the argument string as 1 character. Previously, it could count as 2
    or 3 characters.
  - The return value of the u8_stpncpy, u16_stpncpy, u32_stpncpy functions
    was incorrect.
  - The u8_strcoll, u16_strcoll, u32_strcoll now try harder to give a non-zero
    return value.
* Mon Mar 15 2010 pgajdos@suse.cz
- updated to version 0.9.2.1:
  * The function uc_locale_language now uses the locale of the
    current thread, if a thread-specific locale has been set.
* Tue Nov 24 2009 pgajdos@suse.cz
- initial version of package 0.9.1.1
- spec file taken from
  http://www.pixelbeat.org/patches/libunistring
  (PĂĄdraig Brady <P@draigBrady.com)
- needed by guile 1.9.0 and higher
